CORRELATION_KEY = "correlation_id"
CORRELATION_HEADER = "X-Correlation-ID"

TIME_FORMAT = "%Y-%m-%d %H:%M:%f %Z"
REPLACE_KEY_FOR_TIMESTAMP = "time"
REPLACE_KEY_FOR_EVENT = "msg"

LEVEL_FIELD_NAME = "level"
CORRELATION_FIELD_NAME = "correlation_id"
TIME_FIELD_NAME = "time"
MESSAGE_FIELD_NAME = "msg"

DEFAULT_FILE_LOG = "logs/kilmlogger.log"
